@@ -1,6 +1,6 @@
 ### This file contains an assortment of random airfoils to use
-from aerosandbox.geometry import *
-from aerosandbox.library.aerodynamics import *
+from aerosandbox.geometry.airfoil import Airfoil
+from aerosandbox.library.aerodynamics.viscous import *
 
 generic_cambered_airfoil = Airfoil(
     name="Generic Cambered Airfoil",
@@ -8,10 +8,10 @@ generic_cambered_airfoil = Airfoil(
     CL_function=lambda alpha, Re, mach, deflection,: (  # Lift coefficient function
             (alpha * np.pi / 180) * (2 * np.pi) + 0.4550
     ),
-    CDp_function=lambda alpha, Re, mach, deflection: (  # Profile drag coefficient function
+    CD_function=lambda alpha, Re, mach, deflection: (  # Profile drag coefficient function
             (1 + (alpha / 5) ** 2) * 2 * Cf_flat_plate(Re_L=Re)
     ),
-    Cm_function=lambda alpha, Re, mach, deflection: (  # Moment coefficient function about quarter-chord
+    CM_function=lambda alpha, Re, mach, deflection: (  # Moment coefficient function about quarter-chord
         -0.1
     )
 )
@@ -21,10 +21,10 @@ generic_airfoil = Airfoil(
     CL_function=lambda alpha, Re, mach, deflection,: (  # Lift coefficient function
             (alpha * np.pi / 180) * (2 * np.pi)
     ),
-    CDp_function=lambda alpha, Re, mach, deflection: (  # Profile drag coefficient function
+    CD_function=lambda alpha, Re, mach, deflection: (  # Profile drag coefficient function
             (1 + (alpha / 5) ** 2) * 2 * Cf_flat_plate(Re_L=Re)
     ),
-    Cm_function=lambda alpha, Re, mach, deflection: (  # Moment coefficient function about quarter-chord
+    CM_function=lambda alpha, Re, mach, deflection: (  # Moment coefficient function about quarter-chord
         0
     )  # TODO make this an actual curve!
 )
@@ -35,11 +35,11 @@ e216 = Airfoil(
     CL_function=lambda alpha, Re, mach, deflection: (  # Lift coefficient function
         Cl_e216(alpha=alpha, Re_c=Re)
     ),
-    CDp_function=lambda alpha, Re, mach, deflection: (  # Profile drag coefficient function
+    CD_function=lambda alpha, Re, mach, deflection: (  # Profile drag coefficient function
             Cd_profile_e216(alpha=alpha, Re_c=Re) +
             Cd_wave_e216(Cl=Cl_e216(alpha=alpha, Re_c=Re), mach=mach)
     ),
-    Cm_function=lambda alpha, Re, mach, deflection: (  # Moment coefficient function about quarter-chord
+    CM_function=lambda alpha, Re, mach, deflection: (  # Moment coefficient function about quarter-chord
         -0.15
     ),  # TODO make this an actual curve!
 )
@@ -50,11 +50,11 @@ rae2822 = Airfoil(
     CL_function=lambda alpha, Re, mach, deflection: (  # Lift coefficient function
         Cl_rae2822(alpha=alpha, Re_c=Re)
     ),
-    CDp_function=lambda alpha, Re, mach, deflection: (  # Profile drag coefficient function
+    CD_function=lambda alpha, Re, mach, deflection: (  # Profile drag coefficient function
             Cd_profile_rae2822(alpha=alpha, Re_c=Re) +
             Cd_wave_rae2822(Cl=Cl_rae2822(alpha=alpha, Re_c=Re), mach=mach)
     ),
-    Cm_function=lambda alpha, Re, mach, deflection: (  # Moment coefficient function about quarter-chord
+    CM_function=lambda alpha, Re, mach, deflection: (  # Moment coefficient function about quarter-chord
         -0.05
     ),  # TODO make this an actual curve!
 )
@@ -65,11 +65,11 @@ naca0008 = Airfoil(
     CL_function=lambda alpha, Re, mach, deflection: (  # Lift coefficient function
         Cl_flat_plate(alpha=alpha, Re_c=Re)  # TODO fit this to actual data
     ),
-    CDp_function=lambda alpha, Re, mach, deflection: (  # Profile drag coefficient function
+    CD_function=lambda alpha, Re, mach, deflection: (  # Profile drag coefficient function
             (1 + (alpha / 5) ** 2) * 2 * Cf_flat_plate(Re_L=Re) +  # TODO fit this to actual data
             Cd_wave_Korn(Cl=Cl_flat_plate(alpha=alpha, Re_c=Re), t_over_c=0.08, mach=mach, kappa_A=0.87)
     ),
-    Cm_function=lambda alpha, Re, mach, deflection: (  # Moment coefficient function about quarter-chord
+    CM_function=lambda alpha, Re, mach, deflection: (  # Moment coefficient function about quarter-chord
         0
     ),  # TODO make this an actual curve!
 )
@@ -80,10 +80,10 @@ flat_plate = Airfoil(
     CL_function=lambda alpha, Re, mach, deflection,: (  # Lift coefficient function
         Cl_flat_plate(alpha=alpha, Re_c=Re)
     ),
-    CDp_function=lambda alpha, Re, mach, deflection,: (  # Profile drag coefficient function
+    CD_function=lambda alpha, Re, mach, deflection,: (  # Profile drag coefficient function
             Cf_flat_plate(Re_L=Re) * 2
     ),
-    Cm_function=lambda alpha, Re, mach, deflection: (  # Moment coefficient function
+    CM_function=lambda alpha, Re, mach, deflection: (  # Moment coefficient function
         0
     )  # TODO make this an actual curve!
 )
