@@ -7,7 +7,6 @@ def underlying_function_1D(x):
     return x ** 2 - 8 * x + 5
 
 
-@pytest.fixture
 def interpolated_model():
     np.random.seed(0)  # Set a seed for repeatability.
 
@@ -20,20 +19,24 @@ def interpolated_model():
     )
 
 
-def test_interpolated_model_at_scalar(interpolated_model):
-    assert interpolated_model(5.5) == pytest.approx(underlying_function_1D(5.5))
+def test_interpolated_model_at_scalar():
+    model = interpolated_model()
+    assert model(5.5) == pytest.approx(underlying_function_1D(5.5))
 
 
-def test_interpolated_model_at_vector(interpolated_model):
+def test_interpolated_model_at_vector():
+    model = interpolated_model()
     assert np.all(
-        interpolated_model(np.array([1.5, 2.5, 3.5])) ==
+        model(np.array([1.5, 2.5, 3.5])) ==
         pytest.approx(underlying_function_1D(np.array([1.5, 2.5, 3.5])))
     )
 
 
-def test_interpolated_model_plot(interpolated_model):
-    interpolated_model.plot()
+def test_interpolated_model_plot():
+    model = interpolated_model()
+    model.plot()
 
 
 if __name__ == '__main__':
-    pytest.main()
+    test_interpolated_model_at_scalar()
+    # pytest.main()
